==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/test/http/internal/junit/wizard/HttpTestCaseNewWizard.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.junit.wizard;

import org.eclipse.hyades.models.common.facades.behavioral.ITestSuite;
import org.eclipse.hyades.test.common.TestCommon;
import org.eclipse.hyades.test.common.internal.wizard.TestCaseNewWizard;
import org.eclipse.hyades.test.http.TestHttpImages;
import org.eclipse.hyades.test.http.TestHttpPlugin;

/**
 * Wizard for the JUnit Test Case
 * 
 * @author marcelop
 * @since 0.3.0
 */
public class HttpTestCaseNewWizard
extends TestCaseNewWizard
{
	/**
	 * Constructor for TestCaseNewWizard
	 */
	public HttpTestCaseNewWizard()
	{
		super();

		setWindowTitle(TestHttpPlugin.getString("WIZ_TST_CASE_TTL"));
		setDefaultPageImageDescriptor(TestHttpImages.INSTANCE.getImageDescriptor(TestHttpImages.IMG_WIZBAN_NEW_HTTP_TESTCASE));
	}

	/**
	 * Returns the type for the test case created by this wizard.
	 * @return String
	 */
	protected String getType()
	{
		return TestCommon.HTTP_JUNIT_TEST_CASE_TYPE;
	}
	
	/**
	 * @see org.eclipse.jface.wizard.IWizard#addPages()
	 */
	public void addPages()
	{
		ITestSuite testSuite = (ITestSuite)getSelection().getFirstElement();
		String label = testSuite.getName();

		getAttributeWizardPage().setTitle(TestHttpPlugin.getString("WIZ_TST_CASE_TTL"));
		getAttributeWizardPage().setDescription(TestHttpPlugin.getString("WIZ_TST_CASE_GEN_PG_ATT_DSC", label));
		addPage(getAttributeWizardPage());
	}
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/test/http/internal/junit/wizard/HttpTestCaseNewWizard.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.junit.wizard;

import org.eclipse.hyades.models.common.facades.behavioral.ITestSuite;
import org.eclipse.hyades.test.common.TestCommon;
import org.eclipse.hyades.test.common.internal.wizard.TestCaseNewWizard;
import org.eclipse.hyades.test.http.TestHttpImages;
import org.eclipse.hyades.test.http.TestHttpPlugin;

/**
 * Wizard for the JUnit Test Case
 * 
 * @author marcelop
 * @since 0.3.0
 */
public class HttpTestCaseNewWizard
extends TestCaseNewWizard
{
	/**
	 * Constructor for TestCaseNewWizard
	 */
	public HttpTestCaseNewWizard()
	{
		super();

		setWindowTitle(TestHttpPlugin.getString("WIZ_TST_CASE_TTL"));
		setDefaultPageImageDescriptor(TestHttpImages.INSTANCE.getImageDescriptor(TestHttpImages.IMG_WIZBAN_NEW_HTTP_TESTCASE));
	}

	/**
	 * Returns the type for the test case created by this wizard.
	 * @return String
	 */
	protected String getType()
	{
		return TestCommon.HTTP_JUNIT_TEST_CASE_TYPE;
	}
	
	/**
	 * @see org.eclipse.jface.wizard.IWizard#addPages()
	 */
	public void addPages()
	{
        ITestSuite testSuite = getTestSuite();
        String label = testSuite != null ? testSuite.getName() : ""; //$NON-NLS-1$

		getAttributeWizardPage().setTitle(TestHttpPlugin.getString("WIZ_TST_CASE_TTL")); //$NON-NLS-1$
		getAttributeWizardPage().setDescription(TestHttpPlugin.getString("WIZ_TST_CASE_GEN_PG_ATT_DSC", label)); //$NON-NLS-1$
		addPage(getAttributeWizardPage());
	}
}
